<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'De Plugin aktivéieren',
	'affichage' => 'Uweisen',
	'aide_non_disponible' => 'Dësen Deel vun der Hëllef gëtt et nach net an där Sprooch.',
	'annuler_recherche' => 'D’Sich annuléieren',
	'auteur' => 'Auteur:',
	'avis_acces_interdit' => 'Zougang gespaart.',
	'avis_article_modifie' => 'Opgepasst, den @nom_auteur_modif@ huet un dësem Artikel virun @date_diff@ Minuten geschafft',
	'avis_aucun_resultat' => 'Kee Resultat.',
	'avis_base_inaccessible' => 'Onméiglech mat der Datebank @base@ ze verbannen.',
	'avis_chemin_invalide_1' => 'De Wee deen dir gewielt hutt',
	'avis_chemin_invalide_2' => 'schéngt net ze fonctionnéieren. Gidd op déi läscht Säit zeréck a kontrolléiert d’Informatiounen.',
	'avis_connexion_echec_1' => 'D’Verbannen mat der Datebank huet net fonctionnéiert.',
	'avis_connexion_echec_2' => 'Gidd op déi läscht Säit zeréck a kontrolléiert d’Informatiounen.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Op ville Serveren muss dir d’Ariichte vun engem Zougang un d’Datebank <b>ufroen</b>, ier der se benotze kënnt. Wann der keng Verbindung kritt, kontrolléiert op dat gemaach ass.',
	'avis_connexion_erreur_nom_base' => 'De Numm vun der Datebank däerf nëmme Buschtawen, Zuelen oder Bindestrécher hunn',
	'avis_connexion_ldap_echec_1' => 'D’Verbindung mam LDAP-Server huet net fonctionnéiert.',
	'avis_connexion_ldap_echec_2' => 'Gidd op déi läscht Säit zeréck a kontrolléiert d’Informatiounen.',
	'avis_connexion_ldap_echec_3' => 'Alternativ benotzt keng LDAP-Ënnerstetzung fir d’Benotzer ze verwalten.',
	'avis_deplacement_rubrique' => 'Opgepasst! Dës Rubrik huet @contient_breves@ brève@scb@: wann der se réckelt, klickt dëst Bestätegungs-Feld un.',
	'avis_erreur_connexion_mysql' => 'Fehler bei der SQL-Verbindung',
	'avis_espace_interdit' => '<b>Gespaarten Deel</b><p>SPIP ass schon installéiert.</p>', # MODIF
	'avis_lecture_noms_bases_1' => 'Den Installatiouns-Programm konnt d’Nimm vun den installéierten Datebanken net liesen.',
	'avis_lecture_noms_bases_2' => 'Entweder steet keng Datebank zur Verfügung, oder d’Fonctioun fir d’Datebanken opzelëschten ass aus Sécherheetsgrënn ausgeschalt ginn (dat ass esou bei villen Provider’en).',
	'avis_lecture_noms_bases_3' => 'Am zweete Fall ass et méiglech dat eng Datebank mam selwechte Numm wéi äre Login ka benotzt ginn:',
	'avis_non_acces_page' => 'Dir hutt keen Zougang zu dëser Säit.',
	'avis_operation_echec' => 'Déi Operatioun huet net fonctionnéiert.',
	'avis_operation_impossible' => 'Operatioun onméiglech',
	'avis_suppression_base' => 'OPGEPASST, d’Läsche vun den Daten ka net réckgängeg gemaach ginn',

	// B
	'bouton_acces_ldap' => 'LDAP-Zougang bäiflécken',
	'bouton_ajouter' => 'Bäiflécken',
	'bouton_annuler' => 'Ofbriechen',
	'bouton_demande_publication' => 'D’Verëffentlechung vum Artikel ufroen',
	'bouton_desactive_tout' => 'Alles ausschalten',
	'bouton_desinstaller' => 'De-installéieren',
	'bouton_effacer_tout' => 'ALLES läschen',
	'bouton_envoyer_message' => 'Definitive Message: schécken',
	'bouton_fermer' => 'Zouklappen',
	'bouton_mettre_a_jour_base' => 'Datebank upassen',
	'bouton_modifier' => 'Änneren',
	'bouton_radio_afficher' => 'Weisen',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Op d’Lëscht vun den ugemellte Redaktere kommen',
	'bouton_radio_envoi_annonces_adresse' => 'D’Annonce schécken op d’Adress:',
	'bouton_radio_envoi_liste_nouveautes' => 'D’Lëscht mat de Neiegkeeten schécken',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Net op d’Lëscht vun de Redaktere kommen',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Keng editorial Neiegkeete schécken',
	'bouton_redirection' => 'ËMLEEDUNG',
	'bouton_relancer_installation' => 'D’Ariichte nei ufänken',
	'bouton_suivant' => 'Weider',
	'bouton_tenter_recuperation' => 'Eng Reparatur probéieren',
	'bouton_test_proxy' => 'E Proxy probéieren',
	'bouton_vider_cache' => 'De Cache läschen',

	// C
	'cache_modifiable_webmestre' => 'Dëse Parameter ka vum Webmaster geännert ginn.',
	'calendrier_synchro' => 'Wann dir en <b>iCal</b>-kompatibelen Agenda benotzt, da kënnt dir d’Informatioune mat dësem Site synchroniséieren.',
	'config_activer_champs' => 'Folgend Felder aschalten',
	'config_choix_base_sup' => 'eng Datebank op dësem Server uginn',
	'config_erreur_base_sup' => 'SPIP huet keen Zougrëff op d’Lëscht vun den Datebanken',
	'config_info_base_sup' => 'Wann dir via SPIP aner Datebanke benotze wëllt, mat sengem SQL-Server oder engem aneren, dann deklaréiert se mat dësem Formulaire. Wann dir Felder eidel loosst da ginn d’Daten vun der Haaptdatebank benotzt.',
	'config_info_base_sup_disponibles' => 'Zousätzlech Datebanken kënnen benotzt ginn:',
	'config_info_enregistree' => 'Déi nei Astellung ass gespäichert',
	'config_info_logos' => 'All Element vum Site kann e Logo an e MouseOver-Logo hunn.',
	'config_info_logos_utiliser' => 'Logoe benotzen',
	'config_info_logos_utiliser_non' => 'Kéng Logoe benotzen',
	'config_info_logos_utiliser_survol' => 'MouseOver-Logoe benotzen',
	'config_info_logos_utiliser_survol_non' => 'Kéng MouseOver-Logoe benotzen',
	'config_info_redirection' => 'Wann dës Optioun un ass kënnt dir virtuell Artikele bäiflécken (Linken op aner Artikelen oder Siten).',
	'config_redirection' => 'Virtuell Artikelen',
	'config_titre_base_sup' => 'Ariichte vun enger zousätzlecher Datebank',
	'config_titre_base_sup_choix' => 'Wielt eng zousätzlech Datebank aus',
	'connexion_ldap' => 'Verbindung:',
	'creer_et_associer_un_auteur' => 'En Auteur bäiflécken an ubannen',

	// D
	'date_mot_heures' => 'h',

	// E
	'ecran_securite' => ' + Sécherheetsschëld @version@',
	'email' => 'Email',
	'email_2' => 'Email:',
	'en_savoir_plus' => 'Méi gewuer ginn!',
	'entree_adresse_annuaire' => 'Adress vun der Sammlung',
	'entree_adresse_email' => 'Är Email-Adress',
	'entree_adresse_email_2' => 'Email-Adress',
	'entree_base_donnee_1' => 'Adress vun der Datebank',
	'entree_base_donnee_2' => '(Dës Adress ass oft selwecht wéi déi vun ärem Site, heiansdo ass et "localhost", heiansdo gëtt se eidel gelooss.)',
	'entree_biographie' => 'Kuerz Biographie an e puer Wierder.',
	'entree_chemin_acces' => 'De Wee <b>aginn</b>:',
	'entree_cle_pgp' => 'Äre PGP-Schlëssel',
	'entree_cle_pgp_2' => 'PGP-Schlëssel',
	'entree_contenu_rubrique' => '(Inhalt vun der Rubrik an e puer Wierder.)',
	'entree_identifiants_connexion' => 'Är Zougangs-Informatiounen...',
	'entree_identifiants_connexion_2' => 'Identifikatioun',
	'entree_informations_connexion_ldap' => 'Gidd an dëse Formulaire d’Informatiounen vun ärer LDAP-Verbindung an. Dës Informatioune kritt dir vum Administrateur vum System oder vum Netzwierk.',
	'entree_infos_perso' => 'Wie sidd Dir?',
	'entree_infos_perso_2' => 'Wien ass den Auteur?',
	'entree_interieur_rubrique' => 'An der Rubrik:',
	'entree_liens_sites' => '<b>Link</b> (Referenz, interessante Site...)',
	'entree_login' => 'Äre Login',
	'entree_login_connexion_1' => 'De Login fir d’Verbindung',
	'entree_login_connexion_2' => '(Ass heiansdo selwecht wéi ären FTP-Login, heiansdo gëtt en eidel gelooss)',
	'entree_mot_passe' => 'Äert Passwuert',
	'entree_mot_passe_1' => 'D’Passwuert fir d’Verbindung',
	'entree_mot_passe_2' => '(Ass heiansdo selwecht wéi äert FTP-Passwuert; gëtt heiansdo eidel gelooss)',
	'entree_nom_fichier' => 'Gidd de Numm vum Fichier @texte_compresse@ an:',
	'entree_nom_pseudo' => 'Äre Numm oder äre Pseudonym',
	'entree_nom_pseudo_1' => '(Äre Numm oder äre Pseudonym)',
	'entree_nom_pseudo_2' => 'Numm oder Pseudonym',
	'entree_nom_site' => 'De Numm vun ärem Site',
	'entree_nom_site_2' => 'Numm vum Auteur sengem Site',
	'entree_nouveau_passe' => 'Neit Passwuert',
	'entree_passe_ldap' => 'Passwuert',
	'entree_port_annuaire' => 'D’Port-Nummer vun der Lëscht',
	'entree_signature' => 'Ënnerschrëft',
	'entree_titre_obligatoire' => '<b>Titel</b> [Obligatoresch]<br />',
	'entree_url' => 'D’Adress (URL) vun ärem Site',
	'entree_url_2' => 'Adress (URL) vum Site',
	'erreur_connect_deja_existant' => 'Et gëtt schonns e Server mat dësem Numm',
	'erreur_nom_connect_incorrect' => 'Dëse Server-Numm ass net erlaabt',
	'erreur_plugin_desinstalation_echouee' => 'Desinstallatioun vum Plugin ass feelgeschloen. Dir kënnt en awer ausschalten.',
	'erreur_plugin_fichier_absent' => 'Fichier fehlt',
	'erreur_plugin_fichier_def_absent' => 'Definitiouns-Fichier fehlt',
	'erreur_plugin_nom_fonction_interdit' => 'Fonktiouns-Numm verbueden',
	'erreur_plugin_nom_manquant' => 'Numm vum Plugin fehlt',
	'erreur_plugin_prefix_manquant' => 'Namespace vum Plugin net definéiert',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; fehlt am Definitiouns-Fichier',
	'erreur_plugin_version_manquant' => 'Versioun vum Plugin fehlt',

	// H
	'htaccess_a_simuler' => 'Warnung: D’Astellung vun ärem HTTP-Server ignoréiert @htaccess@ Fichieren. Fir eng gutt Sécherheet musst dier déi Astellung änneren, oder d’Konstanten @constantes@ (astellbar am Fichier mes_options.php) mussen als Valeur aner Repertoire wéi @document_root@ hun.',
	'htaccess_inoperant' => 'htaccess gräift net',

	// I
	'ical_info1' => 'Dës Säit bitt verschidde Méiglechkeeten fir mam Liewe vun dësem Site a Kontakt ze bleiwen.',
	'ical_info2' => 'Fir méi Informatiounen iwwer dës Technik, kuckt an <a href="@spipnet@">der SPIP-Dokumentatioun</a>.',
	'ical_info_calendrier' => 'Et ginn zwee Kalenneren. Deen éischten ass e Plang vum Site mat all den Annoncen vun de publizéierten Artikelen. Deen zweeten huet all editorial Annoncen an är läscht privat Messagen: hien ass mat engem perséinleche Schlëssel fir Iech reservéiert, deen dir zu all Moment ännere kënnt wann dir äert Passwuert ännert.',
	'ical_methode_http' => 'Eroflueden',
	'ical_methode_webcal' => 'Synchronisatioun (webcal://)',
	'ical_texte_js' => 'Eng Javascript-Zeil erlaabt ganz einfach op egal wéi engem anere Siten déi läscht Artikelen vun dësem Site ze weisen.',
	'ical_texte_prive' => 'Dëse Kalenner, den nëmmen just Iech gehéiert, informéiert Iech iwwert déi editorial Aktivitéiten vun dësem Site (Aufgaben a perséinlech Rendezvous’en, virgeschloen Artikelen a Kuerzmeldungen...).',
	'ical_texte_public' => 'Dëse Kalenner erlaabt Iech déi ëffentlech Aktivitéit vun dësem Site ze verfollegen (verëffentlecht Artikelen a Kuerzmeldungen).',
	'ical_texte_rss' => 'Dir kennt nei Siten an egal wat fir engem Programm mam Format XML/RSS (Rich Site Summary) verlinken. SPIP kann och d’Neiegkeeten vun anere Site mat deem Format liesen (verlinkt Siten).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Mailingslëscht',
	'ical_titre_rss' => 'RSS-Fichieren',
	'icone_accueil' => 'Homepage',
	'icone_activer_cookie' => 'De Cookie aschalten',
	'icone_activite' => 'Aktivitéit',
	'icone_admin_plugin' => 'Plugine verwalten',
	'icone_administration' => 'Maintenance',
	'icone_afficher_auteurs' => 'Auteure weisen',
	'icone_afficher_visiteurs' => 'Visiteure weisen',
	'icone_arret_discussion' => 'Net méi un dëser Diskussioun deelhuelen',
	'icone_calendrier' => 'Kalenner',
	'icone_configuration' => 'Astellung',
	'icone_creer_auteur' => 'E neien Auteur bäiflécken an un dësen Artikel bannen',
	'icone_creer_mot_cle' => 'E neit Schlësselwuert bäiflécken an un dësen Artikel bannen',
	'icone_creer_rubrique_2' => 'Nei Rubrik bäiflécken',
	'icone_edition' => 'Ännerung',
	'icone_ma_langue' => 'Meng Sprooch',
	'icone_mes_infos' => 'Meng Informatiounen',
	'icone_mes_preferences' => 'Meng Virléift',
	'icone_modifier_article' => 'Dësen Artikel änneren',
	'icone_modifier_rubrique' => 'Dës Rubrik änneren',
	'icone_publication' => 'Verëffentlechung',
	'icone_relancer_signataire' => 'Beim Ënnerschreiwer nofroen',
	'icone_retour' => 'Zeréck',
	'icone_retour_article' => 'Zeréck bei den Artikel',
	'icone_squelette' => 'Skeletter',
	'icone_suivi_publication' => 'Verëffentlechung verfollegen',
	'icone_supprimer_cookie' => 'Cookie läschen',
	'icone_supprimer_rubrique' => 'Dës Rubrik läschen',
	'icone_supprimer_signature' => 'Dës Ënnerschrëft läschen',
	'icone_valider_signature' => 'Dës Ënnerschrëft bestätegen',
	'image_administrer_rubrique' => 'Dir kënnt dës Rubrik verwalten',
	'impossible_modifier_login_auteur' => 'De Login ka net geännert ginn.', # MODIF
	'impossible_modifier_pass_auteur' => 'D’Passwuert ka net geännert ginn.', # MODIF
	'info_1_article' => '1 Artikel',
	'info_1_auteur' => '1 Auteur',
	'info_1_message' => '1 Message',
	'info_1_mot_cle' => '1 Schlësselwuert',
	'info_1_rubrique' => '1 Rubrik',
	'info_1_visiteur' => '1 Visiteur',
	'info_activer_cookie' => 'Dir kënnt e <b>Cookie</b> aktivéieren, deen iech erlaabt einfach vum ëffentlechen op de private Site ze wiesselen.',
	'info_admin_etre_webmestre' => 'Mir Webmaster-Rechter ginn',
	'info_admin_je_suis_webmestre' => 'Ech si <b>Webmaster</b>',
	'info_admin_statuer_webmestre' => 'Dësem Admin Webmaster-Rechter ginn',
	'info_admin_webmestre' => 'Dësen Admin ass <b>Webmaster</b>',
	'info_administrateur' => 'Administrateur',
	'info_administrateur_1' => 'Administrateur',
	'info_administrateur_2' => 'vum Site (<i>oppassen beim benotzen)',
	'info_administrateur_site_01' => 'Wann dir Administrateur vum Site sidd, ',
	'info_administrateur_site_02' => 'klickt op dëse Link',
	'info_administrateurs' => 'Administrateuren',
	'info_administrer_rubrique' => 'Dir kënnt dës Rubrik verwalten',
	'info_adresse' => 'op der Adress:',
	'info_adresse_url' => 'Adress (URL) vum ëffentleche Site',
	'info_afficher_par_nb' => 'Zortéiert no',
	'info_aide_en_ligne' => 'Online-Hëllef vu SPIP',
	'info_ajout_image' => 'Wann dir engem Artikel Biller als Dokumenter bäifléckt, kann SPIP automatesch Vignetten maachen. Dat erlaabt z.B. automatesch eng Billergalerie ze maachen.',
	'info_ajouter_rubrique' => 'Eng aner Rubrik fir ze verwalten bäiflécken:',
	'info_annonce_nouveautes' => 'D’Neiegkeeten annoncéieren',
	'info_article' => 'Artikel',
	'info_article_2' => 'Artikelen',
	'info_article_a_paraitre' => 'Déi post-datéiert Artikelen',
	'info_articles_02' => 'Artikelen',
	'info_articles_2' => 'Artikelen',
	'info_articles_auteur' => 'Artikelen vun dësem Auteur',
	'info_articles_miens' => 'Meng Artikelen',
	'info_articles_tous' => 'All Artikelen',
	'info_articles_trouves' => 'Artikele fonnt',
	'info_attente_validation' => 'Är Artikelen déi op Bestätegung waarden',
	'info_aucun_article' => 'Keen Artikel',
	'info_aucun_auteur' => 'Keen Auteur',
	'info_aucun_message' => 'Kee Message',
	'info_aucun_rubrique' => 'Keng Rubrik',
	'info_aujourdhui' => 'Haut:',
	'info_auteur_gere_toutes_rubriques_2' => 'Ech verwalten <b>all d’Rubriken</b>', # MODIF
	'info_auteurs' => 'D’Auteuren',
	'info_auteurs_par_tri' => 'Auteuren @partri@',
	'info_auteurs_trouves' => 'Auteure fonnt',
	'info_authentification_externe' => 'Extern Umeldung',
	'info_avertissement' => 'Warnung',
	'info_barre_outils' => 'mat senger Toolbar?',
	'info_base_installee' => 'D’Struktur vun ärer Datebank ass installéiert.',
	'info_bio' => 'Biographie',
	'info_chapeau' => 'Chapo',
	'info_chapeau_2' => 'Chapo:',
	'info_chemin_acces_1' => 'Optiounen: <b>Wee an der Lëscht</b>',
	'info_chemin_acces_2' => 'Dir musst de Wee op d’Informatiounen an der Lëscht uginn. Dës Informatioun ass néideg fir de Profil vun de Benotzer aus der Lëscht ze liesen.',
	'info_chemin_acces_annuaire' => 'Optiounen: <b>Wee an der Lëscht</b>',
	'info_choix_base' => 'Drëtte Schrëtt:',
	'info_classement_1' => '. an @liste@',
	'info_classement_2' => '. an @liste@',
	'info_code_acces' => 'Vergiesst är Zougangs-Informatioune net!',
	'info_config_suivi' => 'Wann dës Adress eng Mailingslëscht ass, da kënnt dier hei d’Adress uginn wou d’Mataarbechter vun dësem Site sech aschreiwe kënnen. Dës Adress kann eng URL sinn (z.B. d’Internetsäit wou een sech aschreiwe kann), oder eng Email-Adress mat engem extra Sujet (z.B.: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Dir kënnt Iech un d’Mailingslëscht vun dësem Site abonnéieren. Dir kritt dann per Email d’Annoncen vun den Artikelen a Kuerzmeldungen déi fir d’Verëffentlechung virgeschloe goufen.',
	'info_confirmer_passe' => 'Bestätegt dat neit Passwuert:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Opgepasst, folgend Felder si geännert ginn. Är Ännerunge sinn also net gespäichert ginn.',
	'info_conflit_edition_differences' => 'Ënnerscheeder:',
	'info_conflit_edition_version_enregistree' => 'Déi gespäichert Versioun:',
	'info_conflit_edition_votre_version' => 'Är Versioun:',
	'info_connexion_base' => 'Versiche mat der Datebank ze verbannen',
	'info_connexion_base_donnee' => 'Verbanne mat ärer Datebank',
	'info_connexion_ldap_ok' => '<b>D’Ubannen un LDAP huet fonctionnéiert.</b><p>Weider bei de nächste Schrëtt.</p>',
	'info_connexion_mysql' => 'Är SQL-Verbindung',
	'info_connexion_ok' => 'D’Verbindung huet geklappt.',
	'info_contact' => 'Kontakt',
	'info_contenu_articles' => 'Inhalt vun den Artikelen',
	'info_contributions' => 'Beiträg',
	'info_creation_paragraphe' => 'Fir nei Abschnitter, loosst einfach eidel Zeilen.',
	'info_creation_rubrique' => 'Ier der kënnt en Artikel schreiwen<br />musst der op mannst eng Rubrik bäiflécken.<br />',
	'info_creation_tables' => 'Tabellen an d’Datebank schreiwen',
	'info_creer_base' => 'Eng nei Datebank <b>ariichten</b>:',
	'info_dans_rubrique' => 'An der Rubrik:',
	'info_date_publication_anterieure' => 'Éischten Redaktiounsdatum:',
	'info_date_referencement' => 'DËSE SITE GOUF VERLINKT:',
	'info_derniere_etape' => 'Et ass fäerdeg!',
	'info_descriptif' => 'Beschreiwung:',
	'info_desinstaller_plugin' => 'läscht d’Daten a schalt de Plugin aus',
	'info_discussion_cours' => 'Aktiv Diskussiounen',
	'info_ecrire_article' => 'Ier dier kënnt en Artikel schreiwen, musst dier op mannst eng Rubrik bäiflécken.',
	'info_email_envoi' => 'Adress vum Absender (optional)',
	'info_email_envoi_txt' => 'Gitt d’Adress un fir Email’en ze schécken (als Default gëtt d’Adress vum Destinataire benotzt):',
	'info_email_webmestre' => 'Email-Adress vum Webmaster',
	'info_envoi_email_automatique' => 'Automatescht Schécken vun Emailen',
	'info_envoyer_maintenant' => 'Elo schécken',
	'info_etape_suivante' => 'Weider bei de nächste Schrëtt',
	'info_etape_suivante_1' => 'Dir kënnt bei de nächste Schrëtt weidergoen.',
	'info_etape_suivante_2' => 'Dir kënnt bei de nächste Schrëtt weidergoen.',
	'info_exceptions_proxy' => 'Ausnam fir de Proxy',
	'info_exportation_base' => 'Export vun der Datebank op @archive@',
	'info_facilite_suivi_activite' => 'Fir déi editorial Aktivitéiten ze verfollegen, ka SPIP d’Demande fir Artikelen ze verëffentlechen oder d’Bestätegungen un eng Mailingslëscht vun de Redakteren schécken.', # MODIF
	'info_fichiers_authent' => 'Authentifikatiouns-Fichieren ".htpasswd"',
	'info_forums_abo_invites' => 'Äre Site huet Forume wou een sech umelle muss; d’Visiteuren ginn also agelueden sech ze enregistréieren.',
	'info_gauche_admin_tech' => '<b>Dës Säit ass fir déi Responsabel vum Site reservéiert.</b><p>Si erlaabt technesch Maintenance-Aarbechten. Fir verschidde vun deene Prozeduren muss een sech iwwer FTP identifizéieren kënnen.</p>',
	'info_gauche_admin_vider' => '<b>Dës Säit ass fir déi Responsabel vum Site reservéiert.</b><p>Si erlaabt technesch Maintenance-Aarbechten. Fir verschidde vun deene Prozeduren muss een sech iwwer FTP identifizéieren kënnen.</p>',
	'info_gauche_auteurs' => 'Hei fannt dir all d’Auteur’en vum Site. Hiren Zoustand ass duerch d’Faarf ugewisen (Admin = gréng; Redakter = giel).',
	'info_gauche_auteurs_exterieurs' => 'Déi extern Auteuren ouni Zougang zum internen Deel sinn duerch eng blo Ikon markéiert, déi geläschten Auteuren duerch eng Dreckskëscht.',
	'info_gauche_messagerie' => 'D’Messagerie erlaabt Iech Messagen un d’Redakteren ze schécken, privat Notizen ze maachen oder Annoncen op d’Startsäit vum privaten Deel ze setzen (wann dir Administrateur sidd).',
	'info_gauche_statistiques_referers' => 'Dës Säit weist d’Lëscht vun de <i>Referer</i>, déi Siten wou e Link op ären Site geklickt gouf, awer nëmmen fir haut: dës Lëscht gëtt all 24 Stonnen op Null gesat.',
	'info_gauche_visiteurs_enregistres' => 'Hei sinn déi ageschriwwe Visiteuren vum ëffentlechen Deel (Forumen op Abonnement).',
	'info_generation_miniatures_images' => 'Miniature vun de Biller maachen',
	'info_gerer_trad_objets' => '@objets@: Iwwersetzungs-Linke änneren',
	'info_hebergeur_desactiver_envoi_email' => 'Verschidden Provideren erlabe net automatesch Emailen ze schécken. An deem Fall fonctionnéiert dat hei net.',
	'info_hier' => 'gëschter:',
	'info_identification_publique' => 'Är ëffentlech Identitéit...',
	'info_image_process' => 'Wielt déi bescht Method fir Vignetten ze maachen an deem dier op d’Bild klickt.',
	'info_image_process2' => 'Wa kee Bild kënnt, dann ass äre Server net fir dës Funktionalitéit ageriicht. Wann dir se wëllt benotzen, kontaktéiert den technesche Responsabelen a frot no der Extensiounen "GD" oder "Imagick".',
	'info_images_auto' => 'Automatesch gerechent Biller',
	'info_informations_personnelles' => 'Perséinlech Informatiounen',
	'info_inscription_automatique' => 'Nei Redakteren automatesch aschreiwen',
	'info_jeu_caractere' => 'Buschtawe-Code vum Site',
	'info_jours' => 'Deeg',
	'info_laisser_champs_vides' => 'dës Felder eidel loossen)',
	'info_langues' => 'Sprooche vum Site',
	'info_ldap_ok' => 'D’Umeldung iwwer LDAP ass installéiert.',
	'info_lien_hypertexte' => 'Link:',
	'info_liste_nouveautes_envoyee' => 'D’Lëscht vun den Ännerunge gouf verschéckt',
	'info_liste_redacteurs_connectes' => 'Lëscht vun den ugemellte Redakteren',
	'info_login_existant' => 'Dëse Login gëtt et schon.',
	'info_login_trop_court' => 'De Login ass ze kuerz.',
	'info_login_trop_court_car_pluriel' => 'De Login muss mindestens @nb@ Zeechen hunn.',
	'info_logos' => 'D’Logoen',
	'info_maximum' => 'Maximum:',
	'info_meme_rubrique' => 'An dëser Rubrik',
	'info_message_en_redaction' => 'Är Messagen an der Aarbecht',
	'info_message_technique' => 'Technesche Message:',
	'info_messagerie_interne' => 'Intern Messagerie',
	'info_mise_a_niveau_base' => 'Upasse vun ärer SQL-Datebank',
	'info_mise_a_niveau_base_2' => '{{Opgepasst!}} Dier hutt eng {al} Versioun vun de SPIP-Fichieren installéiert: är Datebank riskéiert verluer ze goen an äre Site net méi ze fonctionnéieren.<br />{{Installéiert d’SPIP-Fichieren nach eng kéier.}}',
	'info_modification_enregistree' => 'Är Ännerung ass gespäichert',
	'info_modifier_auteur' => 'Auteur änneren:',
	'info_modifier_rubrique' => 'Rubrik änneren:',
	'info_modifier_titre' => 'Änneren: @titre@',
	'info_mon_site_spip' => 'Mäi SPIP-Site',
	'info_moyenne' => 'Duerchschnëtt',
	'info_multi_cet_article' => 'Sprooch vun dësem Artikel:',
	'info_multi_langues_choisies' => 'Wielt hei d’Sproochen aus déi d’Redaktere vun ärem Site kënne benotzen. Déi schonns gebrauchte Sproochen (als éischt ugewisen) kënnen net ausgeschalt ginn.',
	'info_multi_objets' => '@objets@: de Sprooch-Menü aschalten',
	'info_multi_secteurs' => '... nëmme fir d’Haapt-Rubriken?',
	'info_nb_articles' => '@nb@ Artikelen',
	'info_nb_auteurs' => '@nb@ Auteuren',
	'info_nb_messages' => '@nb@ Messagen',
	'info_nb_mots_cles' => '@nb@ Schlësselwierder',
	'info_nb_rubriques' => '@nb@ Rubriken',
	'info_nb_visiteurs' => '@nb@ Visiteuren',
	'info_nom' => 'Numm',
	'info_nom_destinataire' => 'Numm vum Destinataire',
	'info_nom_site' => 'Numm vun ärem Site',
	'info_nombre_articles' => '@nb_articles@ Artikelen,',
	'info_nombre_rubriques' => '@nb_rubriques@ Rubriken,',
	'info_nombre_sites' => '@nb_sites@ Siten,',
	'info_non_deplacer' => 'Net réckelen...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP ka regelméisseg eng Annonce vun de läschte Neiegkeeten vum Site schécken (déi läscht verëffentlecht Artikelen a Kuerzmeldungen).',
	'info_non_envoi_liste_nouveautes' => 'Keng Lëscht vun de Neiegkeete schécken',
	'info_non_modifiable' => 'ka net geännert ginn',
	'info_non_suppression_mot_cle' => 'ech kann dëst Schlësselwuert net läschen.',
	'info_notes' => 'Notten', # war als "Notizen" übersetzt
	'info_nouvel_article' => 'Neien Artikel',
	'info_nouvelle_traduction' => 'Nei Iwwersetzung:',
	'info_numero_article' => 'ARTIKEL NUMMER:',
	'info_obligatoire_02' => '(obligatoresch)', # MODIF
	'info_option_accepter_visiteurs' => 'D’Aschreiwung vu Visiteuren unhuelen',
	'info_option_ne_pas_accepter_visiteurs' => 'D’Aschreiwung vu Visiteuren refuséieren',
	'info_options_avancees' => 'FORTGESCHRATTEN OPTIOUNEN',
	'info_ou' => 'oder...',
	'info_page_interdite' => 'Säit gespaart',
	'info_par_nom' => 'no Numm',
	'info_par_nombre_article' => 'no Zuel vun den Artikelen',
	'info_par_statut' => 'no Status',
	'info_par_tri' => '’(no @tri@)’',
	'info_passe_trop_court' => 'Passwuert ze kuerz.',
	'info_passe_trop_court_car_pluriel' => 'D’Passwuert muss mindestens @nb@ Zeechen hunn.',
	'info_passes_identiques' => 'Déi zwee Passwierder si net selwecht.',
	'info_plus_cinq_car' => 'méi wéi 5 Buschtawen',
	'info_plus_cinq_car_2' => '(Méi wéi 5 Buschtawen)',
	'info_plus_trois_car' => '(Méi wéi 3 Buschtawen)',
	'info_popularite' => 'Popularitéit: @popularite@; Visiten: @visites@',
	'info_post_scriptum' => 'Post-Scriptum',
	'info_post_scriptum_2' => 'Post-Scriptum:',
	'info_pour' => 'fir',
	'info_preview_texte' => 'Dir kënnt de Site ukucken wéi wann all d’Artikelen an d’Kuerzmeldungen (déi op mannst de Status "virgeschloen" hunn) verëffentlecht wären. Soll dës Méiglechkeet fir just d’Administrateuren, fir all d’Redakteren oder fir kee gëllen.', # MODIF
	'info_procedez_par_etape' => 'gitt Schrëtt fir Schrëtt fir',
	'info_procedure_maj_version' => 'D’Update-Prozedur muss ausgeféiert ginn fir är Datebank un déi nei SPIP-Versioun unzepassen.',
	'info_proxy_ok' => 'Test vum Proxy OK.',
	'info_ps' => 'P.S.',
	'info_publier' => 'verëffentlechen',
	'info_publies' => 'Är verëffentlecht Artikelen',
	'info_question_accepter_visiteurs' => 'Wann är Skeletter d’Aschreiwen vu Visiteuren ouni Zougang op de privaten Deel virgesinn, da schalt d’Optioun hei drënner an:',
	'info_question_inscription_nouveaux_redacteurs' => 'Acceptéiert dier d’Aschreiwe vu neie Redakteren direkt vum ëffentleche Site? Wa jo, da kënnen d’Visiteuren sech iwwer en automatesche Formulaire aschreiwen an esou Zougang op de privaten Deel kréien fir hir Artikelen ze proposéieren. <div class="notice">Während der Aschreiwungs-Phase kréien d’Benotzer automatesch en Email mat hiren Zougangs-Informatiounen. Verschidde Provideren verbidden d’Schécken vun Email vun hire Serveuren aus: an deem Fall ass automatescht Aschreiwen onméiglech.</div>',
	'info_qui_edite' => 'Den Auteur @nom_auteur_modif@ huet virun @date_diff@ Minutten un dësem Inhalt geschafft',
	'info_racine_site' => 'Ufank vum Site',
	'info_recharger_page' => 'Lued dës Säit an e puer Sekonne nei.',
	'info_recherche_auteur_zero' => '<b>Kee Resultat fir "@cherche_auteur@".',
	'info_recommencer' => 'Fänkt w.e.g. nei un.',
	'info_redacteur_1' => 'Redakter',
	'info_redacteur_2' => 'mat Zougang zum privaten Deel (<i>recommandéiert</i>)',
	'info_redacteurs' => 'Redakteren',
	'info_redaction_en_cours' => 'AN DER AARBECHT',
	'info_redirection' => 'Ëmleedung',
	'info_redirection_activee' => 'D’Ëmleedung ass aktiv.',
	'info_redirection_desactivee' => 'D’Ëmleedung ass geläscht.',
	'info_refuses' => 'Är refuséiert Artikelen',
	'info_reglage_ldap' => 'Optiounen: <b>Astelle vum LDAP-Import</b>',
	'info_renvoi_article' => '<b>Ëmleedung.</b> Dësen Artikel weist op d’Säit:',
	'info_reserve_admin' => 'Nëmmen d’Administrateure kënnen dës Adress änneren.',
	'info_restreindre_rubrique' => 'D’Verwalten aschränken op d’Rubrik:',
	'info_resultat_recherche' => 'Resultater vun der Sich:',
	'info_rubriques' => 'Rubriken',
	'info_rubriques_02' => 'Rubriken',
	'info_rubriques_trouvees' => 'Rubrike fonnt',
	'info_sans_titre' => 'Ouni Titel',
	'info_selection_chemin_acces' => '<b>Wielt</b> hei de Wee fir den Annuaire:',
	'info_signatures' => 'Ënnerschrëften',
	'info_site' => 'Site',
	'info_site_2' => 'Site:',
	'info_site_min' => 'Site',
	'info_site_reference_2' => 'Verlinkte Site',
	'info_site_web' => 'Website:',
	'info_sites' => 'Siten',
	'info_sites_lies_mot' => 'Un dëst Schlësselwuert gebonne verlinkte Siten',
	'info_sites_proxy' => 'Proxy benotzen',
	'info_sites_trouves' => 'Site fonnt',
	'info_sous_titre' => 'Ënnertitel:',
	'info_statut_administrateur' => 'Administrateur',
	'info_statut_auteur' => 'Zoustand vun dësem Auteur:',
	'info_statut_auteur_2' => 'Ech sinn',
	'info_statut_auteur_a_confirmer' => 'Umeldung ze bestätegen',
	'info_statut_auteur_autre' => 'Aneren Zoustand:',
	'info_statut_redacteur' => 'Redakter',
	'info_statut_utilisateurs_1' => 'Default-Zoustand vun den importéierten Auteuren',
	'info_statut_utilisateurs_2' => 'Wielt den Zoustand vun de Persounen aus dem LDAP-Annuaire déi sech fir d’éischt umellen. Dier kënnt duerno dës Valeur pro Auteur änneren.',
	'info_suivi_activite' => 'Verfolge vun der editorialer Aktivitéit',
	'info_surtitre' => 'Iwwertitel:',
	'info_syndication_integrale_1' => 'Äre Site proposéiert Verlinkungs-Fichier’en (kuckt op "<a href="@url@">@titre@</a>").',
	'info_syndication_integrale_2' => 'Wëllt dir d’Artikelen ganz oder nëmmen e Resumé vun e puer honnert Buschtawen bereedstellen?',
	'info_table_prefix' => 'Dir kënnt de Präfix vun den Tabellen änneren (dat musst dir maachen wann dir e puer Siten op därselwechter Datebank wëllt installéieren). De Präfix muss kléng Buschtawen hunn, ouni Accent an ouni Leerzeechen.',
	'info_taille_maximale_images' => 'SPIP test d’Maximalgréisst vun de Biller déi hien veraarbechte kann (a Millioune Pixel).<br /> Biller déi méi grouss sinn ginn net reduzéiert.',
	'info_taille_maximale_vignette' => 'Maximal-Gréisst vun de Vignetten déi vum System gemaach ginn:',
	'info_terminer_installation' => 'Dier kënnt elo déi normal Ariichtungs-Prozedur ofschléissen.',
	'info_texte' => 'Text',
	'info_texte_explicatif' => 'Erklärung',
	'info_texte_long' => '(den Text ass laang: en ass an e puer Stécker déi bei der Bestätegung zesummen gepecht ginn.)',
	'info_texte_message' => 'Text vun ärem Message',
	'info_texte_message_02' => 'Text vun ärem Message',
	'info_titre' => 'Titel:',
	'info_total' => 'Total:',
	'info_tous_articles_en_redaction' => 'All d’Artikelen an der Aarbecht',
	'info_tous_articles_presents' => 'All d’Artikelen déi an dëser Rubrik verëffentlecht sinn',
	'info_tous_articles_refuses' => 'All déi refuséiert Artikelen',
	'info_tous_les' => 'all:',
	'info_tout_site' => 'De ganze Site',
	'info_tout_site2' => 'Dësen Artikel ass net an déi Sprooch iwwersat.',
	'info_tout_site3' => 'Den Artikel ass an déi Sprooch iwwersat, mais den Original-Artikel ass geännert ginn. D’Iwwersetzung muss ugepasst ginn.',
	'info_tout_site4' => 'Den Artikel ass an déi Sprooch iwwersat, an d’Iwwersetzung ass aktuell.',
	'info_tout_site5' => 'Original-Artikel.',
	'info_tout_site6' => '<b>Opgepasst:</b> nëmmen d’Original-Artikelen si gewisen. D’Iwwersetzunge gehéieren zum Original, mat enger Faarf déi hiren Zoustand weist:',
	'info_traductions' => 'Iwwersetzungen',
	'info_travail_colaboratif' => 'Zesummenaarbecht bei den Artikelen',
	'info_un_article' => 'en Artikel,',
	'info_un_site' => 'e Site,',
	'info_une_rubrique' => 'eng Rubrik,',
	'info_une_rubrique_02' => '1 Rubrik',
	'info_url' => 'URL:',
	'info_url_proxy' => 'URL vum Proxy',
	'info_url_test_proxy' => 'Test-URL',
	'info_urlref' => 'Link:',
	'info_utilisation_spip' => 'Dir kënnt elo de System benotzen...',
	'info_visites_par_mois' => 'Visite pro Mount:',
	'info_visiteur_1' => 'Visiteur',
	'info_visiteur_2' => 'vum ëffentleche Site',
	'info_visiteurs' => 'Visiteuren',
	'info_visiteurs_02' => 'Visiteure vum ëffentleche Site',
	'info_webmestre_forces' => 'D’Webmasteren sinn an <tt>@file_options@</tt> definéiert.',
	'install_adresse_base_hebergeur' => 'Adress vun der Datebank déi dir vum Provider krut',
	'install_connect_ok' => 'Déi nei Datebank gouf ënnert dem Server-Numm @connect@ bäigefléckt.',
	'install_echec_annonce' => 'D’Installatioun wäert wahrscheinlech net fonctionnéieren oder zu engem feelerhafte Site féieren...',
	'install_extension_mbstring' => 'SPIP fonctionnéiert net mat:',
	'install_extension_php_obligatoire' => 'SPIP brauch d’PHP-Extensioun:',
	'install_login_base_hebergeur' => 'Login fir d’Verbindung deen dir vum Provider krut',
	'install_nom_base_hebergeur' => 'Numm vun der Datebank déi dir vum Provider krut:',
	'install_pas_table' => 'Datebank ouni Tafelen',
	'install_pass_base_hebergeur' => 'Passwuert vun der Verbindung dat dir vum Hosting krut',
	'install_php_version' => 'PHP-Version @version@ geet net duer (Minimum = @minimum@)',
	'install_select_langue' => 'Wielt eng Sprooch a klickt op de Knäppche "Weider" fir d’Ariichten ze starten.',
	'install_select_type_db' => 'Gidd den Typ vun der Datebank un:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Datebankserver vum Provider zougewisen',
	'install_table_prefix_hebergeur' => 'Präfix vun den Tafelen deen dir vum Provider krut:',
	'install_tables_base' => 'Datebanktabellen',
	'install_types_db_connus' => 'SPIP ka <b>MySQL</b> (am wäiteste verbreet) an <b>SQLite</b> benotzen.',
	'install_types_db_connus_avertissement' => '<b>PostgreSQL</b> ass och op experimenteller Basis méiglech',
	'instituer_erreur_statut_a_change' => 'Den Zoustand ass schonns geännert ginn',
	'instituer_erreur_statut_non_autorise' => 'Dir kënnt dësen Zoustand net wielen',
	'intem_redacteur' => 'Redakter',
	'intitule_licence' => 'Lizenz',
	'item_accepter_inscriptions' => 'Aschreiwungen unhuelen',
	'item_activer_messages_avertissement' => 'Warnungen aschalten',
	'item_administrateur_2' => 'Administrateur',
	'item_afficher_calendrier' => 'Am Kalenner weisen',
	'item_autoriser_syndication_integrale' => 'D’Artikelen ganz an d’Verlinkungs-Fichieren iwwerdroen',
	'item_choix_administrateurs' => 'd’Administrateuren',
	'item_choix_generation_miniature' => 'Automatesch Miniature vun de Biller maachen.',
	'item_choix_non_generation_miniature' => 'Keng Miniature vun de Biller maachen.',
	'item_choix_redacteurs' => 'd’Redakteren',
	'item_choix_visiteurs' => 'd’Visiteuren vum ëffentleche Site',
	'item_creer_fichiers_authent' => 'D’Fichieren .htpasswd bäiflécken',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'D’Messagerie an den Agenda aschalten',
	'item_mots_cles_association_articles' => 'vun den Artikelen',
	'item_mots_cles_association_rubriques' => 'vun de Rubriken',
	'item_mots_cles_association_sites' => 'vun de verlinkte Siten.',
	'item_non' => 'Neen',
	'item_non_accepter_inscriptions' => 'Keng Aschreiwung unhuelen',
	'item_non_activer_messages_avertissement' => 'Keng Warnungen',
	'item_non_afficher_calendrier' => 'Kee Kalenner weisen',
	'item_non_autoriser_syndication_integrale' => 'Nëmmen e Resumé iwwerdroen',
	'item_non_creer_fichiers_authent' => 'Dës Fichieren net bäiflécken',
	'item_non_messagerie_agenda' => 'D’Messagerie an den Agenda ausschalten',
	'item_non_publier_articles' => 'D’Artikelen net virun dem Verëffentlechungs-Datum fräiginn.',
	'item_nouvel_auteur' => 'Neien Auteur',
	'item_nouvelle_rubrique' => 'Nei Rubrik',
	'item_oui' => 'Jo',
	'item_publier_articles' => 'D’Artikelen fäiginn, egal wéi e Verëffentlechungs-Datum',
	'item_reponse_article' => 'Äntwert op den Artikel',
	'item_visiteur' => 'Visiteur',

	// J
	'jour_non_connu_nc' => '?',

	// L
	'label_bando_outils' => 'Geschirband',
	'label_bando_outils_afficher' => 'Geschir weisen',
	'label_bando_outils_masquer' => 'Geschir verstoppen',
	'label_choix_langue' => 'Wielt är Sprooch aus',
	'label_nom_fichier_connect' => 'Gidd de Numm vun dësem Server un',
	'label_slogan_site' => 'Slogan vum Site',
	'label_taille_ecran' => 'Breet vum Bildschierm', # MODIF
	'label_texte_et_icones_navigation' => 'Navigatiouns-Menü',
	'label_texte_et_icones_page' => 'Uweisen an der Säit',
	'ldap_correspondance' => 'verierft vum Feld @champ@',
	'ldap_correspondance_1' => 'Verierwen vun den LDAP-Felder',
	'ldap_correspondance_2' => 'Gidd de Numm vum LDAP-Feld un deen zu jiddwer SPIP-Feld gehéiert. Loosst eidel fir net auszefëllen, trennt mat Leerzeechen oder Komma fir e puer LDAP-Felder ze probéieren.',
	'lien_ajouter_auteur' => 'Dësen Auteur bäiflécken',
	'lien_ajouter_une_rubrique' => 'Dës Rubrik bäiflécken',
	'lien_email' => 'Email',
	'lien_nom_site' => 'NUMM VUM SITE:',
	'lien_retirer_auteur' => 'Auteur läschen',
	'lien_retirer_rubrique' => 'D’Rubrik zeréckzéien',
	'lien_retirer_tous_auteurs' => 'All d’Auteuren ewech huelen',
	'lien_retirer_toutes_rubriques' => 'All Rubriken zeréckzéien',
	'lien_site' => 'Site',
	'lien_tout_deplier' => 'Alles opklappen',
	'lien_tout_replier' => 'Alles zouklappen',
	'lien_tout_supprimer' => 'Alles läschen',
	'lien_trier_nom' => 'No Numm sortéieren',
	'lien_trier_nombre_articles' => 'No Zuel vun den Artikelen sortéieren',
	'lien_trier_statut' => 'No Status sortéieren',
	'lien_voir_en_ligne' => 'ONLINE KUCKEN:',
	'logo_article' => 'Logo vum Artikel',
	'logo_auteur' => 'Logo vum Auteur',
	'logo_rubrique' => 'Logo vun der Rubrik',
	'logo_site' => 'Logo vun dësem Site',
	'logo_standard_rubrique' => 'Standard-Logo vun de Rubriken',
	'logo_survol' => 'Logo fir de MouseOver',

	// M
	'menu_aide_installation_choix_base' => 'Wiel vun ärer Datebank',
	'module_fichier_langue' => 'Sprooche-Fichier',
	'module_raccourci' => 'Ofkierzung',
	'module_texte_affiche' => 'Gewisenen Text',
	'module_texte_explicatif' => 'Dir kënnt dës Ofkierzungen an de Skelett vum ëffentleche Site abauen. Si ginn automatesch an déi Sproochen iwwersat wou et e Sprooche-Fichier gëtt.',
	'module_texte_traduction' => 'De Sprooche-Fichier « @module@ » gëtt et op:',
	'mois_non_connu' => 'onbekannt',

	// N
	'nouvelle_version_spip' => 'D’Versioun @version@ vu SPIP ass do', # MODIF

	// O
	'onglet_contenu' => 'Inhalt',
	'onglet_declarer_une_autre_base' => 'Eng aner Datebank ariichten',
	'onglet_discuter' => 'Diskutéieren',
	'onglet_interactivite' => 'Interaktivitéit',
	'onglet_proprietes' => 'Propriétéiten',
	'onglet_repartition_actuelle' => 'elo',
	'onglet_sous_rubriques' => 'Ënner-Rubriken',

	// P
	'page_pas_proxy' => 'Dës Säit däerf net duerch de Proxy',
	'pas_de_proxy_pour' => 'Wa néideg dann gitt déi Maschinnen oder Domainer un fir déi dëse Proxy net zielt (z.B.: @exemple@)',
	'plugin_charge_paquet' => 'De Package @name@ lueden',
	'plugin_charger' => 'Eroflueden',
	'plugin_erreur_charger' => 'Fehler: onméiglech @zip@ ze lueden',
	'plugin_erreur_droit1' => 'Den Dossier <code>@dest@</code> ass net beschreiwbar.',
	'plugin_erreur_droit2' => 'Kontrolléiert d’Rechter op dësem Dossier oder installéiert d’Fichieren mat FTP.',
	'plugin_erreur_zip' => 'pclzip: Fehler @status@',
	'plugin_etat_developpement' => 'an der Entwécklung',
	'plugin_etat_experimental' => 'experimentel',
	'plugin_etat_stable' => 'stabil',
	'plugin_etat_test' => 'am Test',
	'plugin_impossible_activer' => 'De Plugin @plugin@ ka net aktivéiert ginn',
	'plugin_info_automatique1' => 'Wann dir d’automatesch Ariichte vun Pluginen erlaabt, dann:',
	'plugin_info_automatique1_lib' => 'Wann dir d’automatesch Ariichte vun dëser Library wëllt erlaben, dann:',
	'plugin_info_automatique2' => 'fléckt den Dossier <code>@rep@</code> bäi;',
	'plugin_info_automatique3' => 'kontrolléiert op de Server kann an dësen Dossier schreiwen.',
	'plugin_info_automatique_creer' => 'am Root-Dossier vum Site ze erstellen.',
	'plugin_info_automatique_exemples' => 'Beispiller:',
	'plugin_info_automatique_ftp' => 'Dir kënnt d’Plugine per FTP an den Dossier <tt>@rep@</tt> iwwerdroën',
	'plugin_info_automatique_lib' => 'Verschidde Plugine musse kënne Fichieren an den Dossier <code>lib/</code> eroflueden, eventuell am Root-Dossier vum Site bäiflécken.',
	'plugin_info_automatique_liste' => 'Är Plugin-Lëscht:',
	'plugin_info_automatique_liste_officielle' => 'déi offiziell Pluginen',
	'plugin_info_automatique_liste_update' => 'Lëschten upassen',
	'plugin_info_automatique_ou' => 'oder...',
	'plugin_info_automatique_select' => 'Wielt e Plugin: SPIP luet en erof an installéiert en am Dossier <code>@rep@</code>; wann de Plugin schonns do ass gëtt en Update gemaach.',
	'plugin_info_credit' => 'Krediter',
	'plugin_info_erreur_xml' => 'D’Deklaratioun vun dësem Plugin ass falsch',
	'plugin_info_install_ok' => 'D’Ariichten huet geklappt',
	'plugin_info_necessite' => 'Brauch:',
	'plugin_info_non_compatible_spip' => 'Dëse Plugin ass mat der heiter SPIP-Versioun net kompatibel',
	'plugin_info_plugins_dist_1' => 'Déi hei Plugine sinn an den Dossier @plugins_dist@ gelueden an ageschalt.',
	'plugin_info_plugins_dist_2' => 'Si kënne net ausgeschalt ginn.',
	'plugin_info_telecharger' => 'Eroflueden vun @url@ an Ariichten an @rep@',
	'plugin_librairies_installees' => 'Installéiert Librairie’en',
	'plugin_necessite_lib' => 'Dëse Plugin brauch d’Librairie @lib@',
	'plugin_necessite_plugin' => 'De Plugin @plugin@ muss mindestens op der Versioun @version@ sinn.', # MODIF
	'plugin_necessite_plugin_sans_version' => 'Brauch de Plugin @plugin@',
	'plugin_necessite_spip' => 'SPIP muss mindestens op der Versioun @version@ sinn.',
	'plugin_source' => 'Quell: ',
	'plugin_titre_automatique' => 'Automatescht Ariichten',
	'plugin_titre_automatique_ajouter' => 'Pluginen bäiflécken',
	'plugin_titre_installation' => 'Ariichte vum Plugin @plugin@',
	'plugin_titre_modifier' => 'Meng Pluginen',
	'plugin_zip_active' => 'Fuert weider fir anzeschalten',
	'plugin_zip_adresse' => 'gitt hei d’Adress vun engem Plugin-Zip-Fichier un, oder d’Adress vun enger Lëscht vu Pluginen.',
	'plugin_zip_adresse_champ' => 'Adress vum Plugin oder vun der Lëscht ',
	'plugin_zip_content' => 'Folgend Fichieren sinn dran (@taille@),<br />prëtt fir am Dossier <code>@rep@</code> ageriicht ze ginn',
	'plugin_zip_installe_finie' => 'De Fichier @zip@ ass entpaakt an ageriicht ginn.',
	'plugin_zip_installe_rep_finie' => 'De Fichier @zip@ ass entpaakt an am Dossier @rep@ ageriicht  ginn',
	'plugin_zip_installer' => 'Dir kënnt en elo ariichten.',
	'plugin_zip_telecharge' => 'De Fichier @zip@ ass erofgeluede ginn',
	'plugins_actif_aucun' => 'Et ass kee Plugin ageschalt.',
	'plugins_actif_un' => '1 Plugin ageschalt.',
	'plugins_actifs' => '@count@ aktivéiert Pluginen.',
	'plugins_actifs_liste' => 'Aktiv',
	'plugins_compte' => '@count@ Pluginen',
	'plugins_disponible_un' => '1 Plugin ze kréien.',
	'plugins_disponibles' => '@count@ Pluginen verfügbar.',
	'plugins_erreur' => 'Fehler an de Pluginen: @plugins@',
	'plugins_liste' => 'Lëscht vun de Pluginen',
	'plugins_liste_dist' => 'Gespaarte Pluginen',
	'plugins_recents' => 'Nei Pluginen.',
	'plugins_tous_liste' => 'All',
	'plugins_vue_hierarchie' => 'Hierarchie',
	'plugins_vue_liste' => 'Lëscht',
	'protocole_ldap' => 'Versioun vum Protokoll:',

	// Q
	'queue_executer_maintenant' => 'Elo ausféieren',
	'queue_info_purger' => 'Dir kënnt all Aarbechten déi nach ustinn läschen an d’Lëscht mat de periodeschen Aarbechten nei starten', # MODIF
	'queue_nb_jobs_in_queue' => '@nb@ Aarbechten an der Waardeschläif', # MODIF
	'queue_next_job_in_nb_sec' => 'Nächst Aarbecht an @nb@ s', # MODIF
	'queue_no_job_in_queue' => 'Kéng Aarbecht an der Waardeschläif', # MODIF
	'queue_one_job_in_queue' => '1 Aarbecht an der Waardeschläif', # MODIF
	'queue_purger_queue' => 'D’Aarbechtslëscht nei starten', # MODIF
	'queue_titre' => 'Aarbechtslëscht', # MODIF

	// R
	'repertoire_plugins' => 'Dossier:',
	'required' => '(obligatoresch)', # MODIF

	// S
	'sans_heure' => 'ouni Zäit',
	'statut_admin_restreint' => '(restriktiven Admin)', # MODIF

	// T
	'tache_cron_asap' => 'CRON-Aarbecht @function@ (ASAP)',
	'tache_cron_secondes' => 'CRON-Aarbecht @function@ (all @nb@ s)',
	'taille_cache_image' => 'Déi automatësch berechent Biller (Vignette vun Dokumenter, graphesch Titelen, mathematesch Formelen am TeX-Format...) brauchen am Dossier @dir@ eng Plaz vun @taille@.',
	'taille_cache_infinie' => 'De Cache vun dësem Site ass net an der Gréisst beschränkt.',
	'taille_cache_maxi' => 'SPIP probéiert d’Gréisst vum Cache vun dësem Site op ongeféier <b>@octets@</b> ze beschränken.',
	'taille_cache_moins_de' => 'D’Gréisst vum Cache ass méi kléng wéi @octets@.',
	'taille_cache_octets' => 'D’Gréisst vum Cache ass momentan ongeféier @octets@.',
	'taille_cache_vide' => 'De Cache ass eidel.',
	'taille_repertoire_cache' => 'Gréisst vum Cache-Dossier',
	'text_article_propose_publication' => 'Fir d’Verëffentlechung virgeschloen Artikel.',
	'texte_acces_ldap_anonyme_1' => 'Verschidden LDAP-Serveren erlabe keen anonymen Zougang. An deem Fall musst dir en initialen Zougang uginn fir Informatiounen am Annuaire kënnen ze sichen. An deenen meeschte Fäll kënnt dier dës Felder eidel loossen.',
	'texte_admin_effacer_01' => 'Dës Prozedur läscht <i>alles</i> aus der Datebank, och <i>all</i> Zougäng vun de Redakteren an Administrateuren. Duerno musst dir SPIP nei installéieren fir eng nei Datebank an den éischten Admin-Zougang bäizeflécken.',
	'texte_adresse_annuaire_1' => '(Wann ären Annuaire op därselwechter Maschinn installéiert ass, dann ass et hei wahrscheinlech "localhost".)',
	'texte_ajout_auteur' => 'Dësen Auteur gouf beim Artikel bäigefléckt:',
	'texte_annuaire_ldap_1' => 'Wann dir Zougang zu engem Annuaire (LDAP) hutt, da kënnt dir e benotzen fir automatesch d’Benotzer vu SPIP ze importéieren.',
	'texte_article_statut' => 'Dësen Artikel ass:',
	'texte_article_virtuel' => 'Virtuellen Artikel',
	'texte_article_virtuel_reference' => '<b>Virtuellen Artikel:</b> am SPIP agedroen, mais op eng aner URL ëmgeleet. Fir d’Ëmleedung ze läschen, läscht d’URL hei driwwer.',
	'texte_aucun_resultat_auteur' => 'Kee Resultat fir "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'De Site kann Iech dauernd d’Lëscht vun den ugemellten Redaktere weisen, fir dat dier hinnen direkt Messagen kënnt schécken. Dir kënnt entscheeden net an der Lëscht ze sinn (dir sidd "onsiichtbar" fir déi aner Benotzer).',
	'texte_auteurs' => 'D’AUTEUREN',
	'texte_choix_base_1' => 'Wielt är Datebank:',
	'texte_choix_base_2' => 'Den SQL-Server huet e puer Datebanken.',
	'texte_choix_base_3' => '<b>Wielt</b> hei déi déi Iech vun ärem Provider zougewise gouf:',
	'texte_choix_table_prefix' => 'Präfix vun den Tabellen:',
	'texte_compte_element' => '@count@ Element',
	'texte_compte_elements' => '@count@ Elementer',
	'texte_conflit_edition_correction' => 'Kontrolléiert d’Ënnerscheeder tëschent den zwou Versioune vum Text; dir kënnt är Ännerungen och kopéieren an erëm ufänken.',
	'texte_connexion_mysql' => 'Kuckt an der Informatioun vun ärem Provider: dir musst do den Datebank-Server an är perséinlech Identifikatioun fannen.',
	'texte_contenu_article' => '(Inhalt vum Artikel an e puer Wierder.)',
	'texte_contenu_articles' => 'Jee no Design vun ärem Site kënnt dier wielen dat verschidden Elementer vun den Artikelen net benotzt ginn. Benotzt d’Lëscht hei drënner fir unzeginn wéi eng Elementer e kann benotzen.',
	'texte_crash_base' => 'Wann är Datebank ofgestierzt ass, da kënnt dir eng automatesch Reparatur probéieren.',
	'texte_creer_rubrique' => 'Ier dir kënnt en Artikel schreiwen, musst dir eng Rubrik bäiflécken setzen.',
	'texte_date_creation_article' => 'ARTIKEL BÄIGEFLÉCKT DEN:',
	'texte_date_creation_objet' => 'Kreatiouns-Datum:', # on ajoute le &quot;:&quot;
	'texte_date_publication_anterieure' => 'ÉISCHTEN REDAKTIOUNS-DATUM:',
	'texte_date_publication_anterieure_nonaffichee' => 'Éischten Redaktiouns-Datum net weisen.',
	'texte_date_publication_article' => 'VERËFFENTLECHT DEN:',
	'texte_date_publication_objet' => 'Datum vun der Verëffentlechung:',
	'texte_descriptif_rapide' => 'Kuerz Beschreiwung',
	'texte_effacer_base' => 'D’SPIP-Datebank läschen',
	'texte_effacer_statistiques' => 'Statistik läschen',
	'texte_en_cours_validation' => 'Déi Inhalter hei drënner waarden op d’Verëffentlechung.',
	'texte_enrichir_mise_a_jour' => 'Dir kënnt de Layout verbesseren mat "typographeschen Ofkierzungen".',
	'texte_fichier_authent' => '<b>Soll SPIP déi speziell Fichieren <tt>.htpasswd</tt> an <tt>.htpasswd-admin</tt> am Dossier @dossier@ bäiflécken?</b><p>Dës Fichieren kënnen den Zougang vun den Redakteren an Administrateuren op verschidden Deeler vum Site kontrolléieren (z.B. externe Statistik-Programm).</p><p>Wann dir dat net braucht, da loosst dës Optioun op sengem Default (kéng Fichiere bäiflécken).</p>', # MODIF
	'texte_informations_personnelles_1' => 'De System gëtt Iech elo e personaliséierten Zougang zum Site.',
	'texte_informations_personnelles_2' => '(N.B.: Wann äre Login bei dëser Re-Installatioun nach fonctionnéiert, da kënnt Dier',
	'texte_introductif_article' => '(Aleedung vum Artikel.)',
	'texte_jeu_caractere' => 'Mir roden Iech ob ärem Site dat universaalt Alphabet (<tt>UTF-8</tt>) ze gebrauchen: et kann Texter an alle Sproochen uweisen, an huet keng Kompatibilitéits-Problemer méi mat de moderne Browseren.',
	'texte_jeu_caractere_3' => 'Äre Site benotzt elo den Character-Set:',
	'texte_jeu_caractere_4' => 'Wann dat net der Realitéit vun ären Daten entsprécht (z.B. no enger Restauratioun vun der Datebank), oder wann dir <em>dësen Site nei ufänkt</em> an dir ob en aneren Character-Set ëmschalten wëllt, dann gitt en elo hie un:',
	'texte_login_ldap_1' => '(Eidel loossen fir en anonymen Zougang,  oder de kompletten Wee uginn, z.B. " <tt>uid=muller, ou=users, dc=domain, dc=com</tt> ".)',
	'texte_login_precaution' => 'Opgepasst! Dëst ass de Login mat dem dier ugemellt sidd. Benotzt dëse Formulaire virsiichteg...',
	'texte_messagerie_agenda' => 'Eng Messagerie erlaabt de Redakteren vum Site direkt am privaten Deel mateneen ze schwätzen. Si ass en Deel vum Agenda.',
	'texte_mise_a_niveau_base_1' => 'Dir hutt eng Upassung vun de SPIP-Fichier’en gemaach. Elo muss d’Datebank ugepasst ginn.',
	'texte_modifier_article' => 'Den Artikel änneren:',
	'texte_multilinguisme' => 'Wann dir Objekter a méi Sprooche mat enger komplexer Navigatioun wëllt benotzen, da kënnt dir e Menü fir d’Sproochwiel bei den Objekter aschalten.',
	'texte_multilinguisme_trad' => 'Dir kënnt och eng Gestioun vun de Linken tëschent den Iwwersetzunge vu verschidden Objekter aschalten.',
	'texte_non_compresse' => '<i>net kompriméiert</i> (äre Server erlaabt dat net)',
	'texte_nouvelle_version_spip_1' => 'Dir hutt eng nei Versioun vu SPIP ageriicht.',
	'texte_nouvelle_version_spip_2' => 'Dës nei Versioun verlaangt e méi kompletten Update wéi normalerweis. Wann Dir de Webmaster vum Site sidd, läscht de Fichier @connect@ a fuert mat dem Ariichte weider fir Zougangsberechtegunge fir d’Datebank unzepassen.<p>(N.B.: wann dir är Berechtegunge vergiess hutt, kuckt am Fichier @connect@ ier Dir e läscht...)</p>',
	'texte_operation_echec' => 'Gidd op déi läscht Säit zeréck, wielt eng aner Datebank oder fléckt eng bäi. Kontrolléiert d’Informatioune vun ärem Provider.',
	'texte_plus_trois_car' => 'méi wéi 3 Buschtawen',
	'texte_plusieurs_articles' => 'E puer Artikele fonnt vum "@cherche_auteur@":',
	'texte_port_annuaire' => '(D’Default-Valeur ass normalerweis déi richteg.)',
	'texte_presente_plugin' => 'Dës Säit weist wéi eng Pluginen do sinn. Dir kënnt d’Pluginen aschalten andeem dier se ukräizt.',
	'texte_proposer_publication' => 'Wann ären Artikel fäerdeg ass,<br />kënnt der d’Verëffentlechung virschloen.',
	'texte_proxy' => 'A bestëmmte Fäll (Intranet, geschützte Netzer...) kann et néideg sinn iwwert en <i>HTTP-Proxy</i> ze fueren fir un déi verlinkte Siten ze kommen. An deem Fall, gitt hei seng Adress un, ënner der Form @proxy_en_cours@. Normalerweis bleift dëst Feld eidel.',
	'texte_publication_articles_post_dates' => 'Wat soll SPIP mat den Artikelen maachen, wou de Verëffentlechungs-Datum an der Zukunft ass?',
	'texte_rappel_selection_champs' => '[Vergiesst net dëst Feld richteg ze wielen.]',
	'texte_recalcul_page' => 'Wann dir eng eenzeg Säit nei berechne wëllt, maacht dat léiwer iwwert den ëffentlechen Deel a benotzt de Knäppchen "Nei rechnen".',
	'texte_recuperer_base' => 'Datebank flécken',
	'texte_reference_mais_redirige' => 'Artikel aus dem SPIP-Site, awer op eng aner URL ëmgeleet.',
	'texte_requetes_echouent' => '<b>Wa verschidden SQL-Query’en systematesch an ouni siichtbar Ursaach feelschloen, ass et méiglech dat et un der Datebank selwer hänkt.</b><p>Ären SQL-Serveur kann seng Tabelle flécken wann se futti sinn. Dir kënnt hei eng Reparatur probéieren; wann et net geet, kopéiert den Bildschierm, do si villäicht Hiweiser op dat wat net fonctionnéiert...</p><p> Wann de Problem weider besteet, kontaktéiert äre Provider.</p>',
	'texte_selection_langue_principale' => 'Hei kënnt der "d’Haapt-Sprooch" vum Site wielen. Dës Wiel forcéiert Iech net nëmmen an där Sprooch ze schreiwen, mais: <ul><li>setzt den Default-Format vun den Datumen um ëffentlechen Site;</li><li>setzt den typographesche Motor dee SPIP benotze soll fir Texter ze weisen;</li><li>setzt d’Sprooch déi an den ëffentlechen Formulaire benotzt gëtt;</li><li>setzt d’Default-Sprooch am privaten Deel vum Site.</li></ul>',
	'texte_sous_titre' => 'Ënnertitel',
	'texte_statistiques_visites' => '(donkel:  Sonndeg / Kurv: Evolutioun vun der Moyenne)',
	'texte_statut_attente_validation' => 'waart op d’Bestätegung',
	'texte_statut_publies' => 'verëffentlecht',
	'texte_statut_refuses' => 'refuséiert',
	'texte_suppression_fichiers' => 'Benotzt dës Prozedur fir all d’Fichieren aus dem Cache ze läschen. Sou kënnt dir z.B. all d’Säiten nei rechnen, wann dir grouss Ännerungen um Layout oder der Struktur vum Site gemaach hutt.',
	'texte_sur_titre' => 'Iwwertitel',
	'texte_table_ok' => ': dës Tafel ass OK.',
	'texte_tentative_recuperation' => 'Reparatur-Versuch',
	'texte_tenter_reparation' => 'Eng Reparatur vun der Datebank probéieren',
	'texte_test_proxy' => 'Fir de Proxy ze probéieren, gitt hei d’Adress vun engem Web-Site un.',
	'texte_titre_02' => 'Titel:',
	'texte_titre_obligatoire' => '<b>Titel</b> [Obligatoresch]',
	'texte_travail_article' => '@nom_auteur_modif@ huet un dësem Artikel virun @date_diff@ Minutte geschafft',
	'texte_travail_collaboratif' => 'Wann öfters e puer Redakteren un deem selwechten Artikel schaffen, kann de System déi rezent "oppen" Artikele weisen fir gläichzäiteg Ännerungen ze verhënneren. Dës Optioun ass par défaut ausgeschalt fir net andauernd Warnungen ze weisen.',
	'texte_vide' => 'eidel',
	'texte_vider_cache' => 'De Cache läschen',
	'titre_admin_tech' => 'Maintenance',
	'titre_admin_vider' => 'Maintenance',
	'titre_ajouter_un_auteur' => 'En Auteur bäiflécken',
	'titre_ajouter_un_mot' => 'E Schlësselwuert bäiflécken',
	'titre_cadre_afficher_article' => 'D’Artikele weisen',
	'titre_cadre_afficher_traductions' => 'Zoustand vun den Iwwersetzunge weisen fir dës Sproochen:',
	'titre_cadre_ajouter_auteur' => 'AUTEUR BÄIFLÉCKEN:',
	'titre_cadre_interieur_rubrique' => 'An der Rubrik',
	'titre_cadre_numero_auteur' => 'AUTEUR NUMMER',
	'titre_cadre_numero_objet' => '@objet@ NUMMER:',
	'titre_cadre_signature_obligatoire' => '<b>Ënnerschrëft</b> [Obligatoresch]<br />',
	'titre_config_contenu_notifications' => 'Meldungen',
	'titre_config_contenu_prive' => 'Am privaten Deel',
	'titre_config_contenu_public' => 'Um ëffentleche Site',
	'titre_config_fonctions' => 'Astelle vum Site',
	'titre_config_langage' => 'Sprooch astellen',
	'titre_configuration' => 'Astelle vum Site',
	'titre_configurer_preferences' => 'Är Virléiften astellen',
	'titre_conflit_edition' => 'Konflikt während der Ännerung',
	'titre_connexion_ldap' => 'Optiounen: <b>Är LDAP-Verbindung</b>',
	'titre_groupe_mots' => 'WUERT-GRUPP:',
	'titre_identite_site' => 'Identitéit vum Site',
	'titre_langue_article' => 'Sprooch vum Artikel',
	'titre_langue_rubrique' => 'Sprooch vun der Rubrik',
	'titre_langue_trad_article' => 'SPROOCH AN IWWERSETZUNGE VUM ARTIKEL',
	'titre_les_articles' => 'D’ARTIKELEN',
	'titre_messagerie_agenda' => 'Messagerie an Agenda',
	'titre_naviguer_dans_le_site' => 'Am Site surfen...',
	'titre_nouvelle_rubrique' => 'Nei Rubrik',
	'titre_numero_rubrique' => 'RUBRIK NUMMER:',
	'titre_page_articles_edit' => 'Änneren: @titre@',
	'titre_page_articles_page' => 'D’Artikelen',
	'titre_page_articles_tous' => 'De ganzen Site',
	'titre_page_calendrier' => 'Kalenner @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Astelle vum Site',
	'titre_page_delete_all' => 'definitiv an irreversibel läschen',
	'titre_page_recherche' => 'Resultater vun der Sich @recherche@',
	'titre_page_statistiques_referers' => 'Statistik (Linken déi era kommen)',
	'titre_page_upgrade' => 'SPIP updaten',
	'titre_publication_articles_post_dates' => 'Verëffentleche vun den post-datéierten Artikelen',
	'titre_reparation' => 'Reparatur',
	'titre_suivi_petition' => 'Suivi vun de Petitiounen',
	'tls_ldap' => 'Transport Layer Security:',
	'trad_article_traduction' => 'All d’Versioune vun dësem Artikel:',
	'trad_delier' => 'Dës Iwwersetzunge net méi verbannen',
	'trad_lier' => 'Dësen Artikel ass eng Iwwersetzung vum Artikel Nummer:',
	'trad_new' => 'Eng nei Iwwersetzung schreiwen',

	// U
	'utf8_convert_erreur_orig' => 'Fehler: de Character-Set @charset@ gëtt net ënnerstëtzt.',

	// V
	'version' => 'Versioun:'
);
